@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 
-from .common import match1, maybe_print, download_urls, get_filename, parse_host, set_proxy, unset_proxy, get_content, dry_run
+from .common import match1, maybe_print, download_urls, get_filename, parse_host, set_proxy, unset_proxy, get_content, dry_run, player
 from .common import print_more_compatible as print
 from .util import log
 from . import json_output
 import os
+import sys
 
 class Extractor():
     def __init__(self, *args):
@@ -32,7 +33,8 @@ class VideoExtractor():
         self.out = False
         self.ua = None
         self.referer = None
-        self.danmuku = None
+        self.danmaku = None
+        self.lyrics = None
 
         if args:
             self.url = args[0]
@@ -105,7 +107,7 @@ class VideoExtractor():
         if 'quality' in stream:
             print("      quality:       %s" % stream['quality'])
 
-        if 'size' in stream and stream['container'].lower() != 'm3u8':
+        if 'size' in stream and 'container' in stream and stream['container'].lower() != 'm3u8':
             if stream['size'] != float('inf')  and stream['size'] != 0:
                 print("      size:          %s MiB (%s bytes)" % (round(stream['size'] / 1048576, 1), stream['size']))
 
@@ -130,6 +132,8 @@ class VideoExtractor():
         print("        url:         %s" % self.url)
         print()
 
+        sys.stdout.flush()
+
     def p(self, stream_id=None):
         maybe_print("site:                %s" % self.__class__.name)
         maybe_print("title:               %s" % self.title)
@@ -154,9 +158,10 @@ class VideoExtractor():
                 for stream in itags:
                     self.p_stream(stream)
             # Print all other available streams
-            print("    [ DEFAULT ] %s" % ('_' * 33))
-            for stream in self.streams_sorted:
-                self.p_stream(stream['id'] if 'id' in stream else stream['itag'])
+            if self.streams_sorted:
+                print("    [ DEFAULT ] %s" % ('_' * 33))
+                for stream in self.streams_sorted:
+                    self.p_stream(stream['id'] if 'id' in stream else stream['itag'])
 
         if self.audiolang:
             print("audio-languages:")
@@ -164,6 +169,8 @@ class VideoExtractor():
                 print("    - lang:          {}".format(i['lang']))
                 print("      download-url:  {}\n".format(i['url']))
 
+        sys.stdout.flush()
+
     def p_playlist(self, stream_id=None):
         maybe_print("site:                %s" % self.__class__.name)
         print("playlist:            %s" % self.title)
@@ -195,7 +202,13 @@ class VideoExtractor():
             else:
                 # Download stream with the best quality
                 from .processor.ffmpeg import has_ffmpeg_installed
-                stream_id = self.streams_sorted[0]['id'] if 'id' in self.streams_sorted[0] else self.streams_sorted[0]['itag']
+                if has_ffmpeg_installed() and player is None and self.dash_streams or not self.streams_sorted:
+                    #stream_id = list(self.dash_streams)[-1]
+                    itags = sorted(self.dash_streams,
+                                   key=lambda i: -self.dash_streams[i]['size'])
+                    stream_id = itags[0]
+                else:
+                    stream_id = self.streams_sorted[0]['id'] if 'id' in self.streams_sorted[0] else self.streams_sorted[0]['itag']
 
             if 'index' not in kwargs:
                 self.p(stream_id)
@@ -226,9 +239,11 @@ class VideoExtractor():
                           output_dir=kwargs['output_dir'],
                           merge=kwargs['merge'],
                           av=stream_id in self.dash_streams)
+
             if 'caption' not in kwargs or not kwargs['caption']:
-                print('Skipping captions or danmuku.')
+                print('Skipping captions or danmaku.')
                 return
+
             for lang in self.caption_tracks:
                 filename = '%s.%s.srt' % (get_filename(self.title), lang)
                 print('Saving %s ... ' % filename, end="", flush=True)
@@ -237,11 +252,18 @@ class VideoExtractor():
                           'w', encoding='utf-8') as x:
                     x.write(srt)
                 print('Done.')
-            if self.danmuku is not None and not dry_run:
+
+            if self.danmaku is not None and not dry_run:
                 filename = '{}.cmt.xml'.format(get_filename(self.title))
                 print('Downloading {} ...\n'.format(filename))
                 with open(os.path.join(kwargs['output_dir'], filename), 'w', encoding='utf8') as fp:
-                    fp.write(self.danmuku)
+                    fp.write(self.danmaku)
+
+            if self.lyrics is not None and not dry_run:
+                filename = '{}.lrc'.format(get_filename(self.title))
+                print('Downloading {} ...\n'.format(filename))
+                with open(os.path.join(kwargs['output_dir'], filename), 'w', encoding='utf8') as fp:
+                    fp.write(self.lyrics)
 
             # For main_dev()
             #download_urls(urls, self.title, self.streams[stream_id]['container'], self.streams[stream_id]['size'])
